import logging
from django.conf import settings
from django.urls.base import reverse
from django.http import HttpResponseRedirect


logger = logging.getLogger(__name__)


try:
    PP = settings.PARAMS_URL_CONF
except AttributeError:
    msg = 'Django URL params! PARAMS_URL_CONF is missing using default URL_CONF.'
    logger.info(msg)
    PP = settings.ROOT_URLCONF


def param_redirect(request, viewname, *args):
    """ Redirect and keep URL parameters if any. """
    url = reverse(viewname, PP, args)
    params = request.GET.urlencode().split('&')

    if hasattr(request, 'cparam'):
        for k, v in request.cparam.items():
            params.append('{0}={1}'.format(k, v))

    new_params = '&'.join(x for x in params if x != '')
    if len(new_params) > 0:
        return HttpResponseRedirect('{0}?{1}'.format(url, new_params))
    return HttpResponseRedirect(url)



import setuptools


LONG_DESCRIPTION = """Django URL params

This library contains code to keep parameters in django URL 
during Django redirections.
"""


setuptools.setup(
    name="django-url-params",
    version="1.0.1",
    author="Goran Krsman",
    author_email="goran@klikoglasi.com",
    description="Keep URL parameters in Django redirect.",
    long_description=LONG_DESCRIPTION,
    long_description_content_type="text/markdown",
    license="MIT",
    url="https://github.com/gkrsman/django-url-params",
    packages=setuptools.find_packages(),
    keywords=['django', 'url', 'redirect', 'django-url-params'],
    classifiers=[
        "Environment :: Web Environment",
        "Framework :: Django",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
